function v=compute_tangential_surge_c1(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes tangential_surge_c1
% Script automatically generated by fit_tangential_surge_c1.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.73211
% RMSE  = 18.5884
% MEAN  = 100.0913
% RANGE = 37.5266 - 181.2973

beta( 1 )= 1.3501e-02 ;
beta( 2 )= 2.1361e-01 ;
beta( 3 )= 1.7668e+02 ;
beta( 4 )= 6.8438e-01 ;
beta( 5 )= 7.0037e-02 ;
beta( 6 )= 7.0185e-01 ;
beta( 7 )= 4.0904e-01 ;
beta( 8 )= 1.4141e+01 ;
beta( 9 )= 4.8384e-01 ;

v=beta(1) * a.^beta(2) .* max(w,beta(3)).^beta(4) .* rmax.^beta(5) .* r35.^beta(6) .* (beta(7) + cos((phi-beta(8))*pi/180)) .* vt.^beta(9);
